summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorMaximilian Albert <maximilian.albert@gmail.com>2008-07-08 21:18:50 +0000
committercilix42 <cilix42@users.sourceforge.net>2008-07-08 21:18:50 +0000
commitd4f8d56e508fdc427992fb950c67a98af765f187 (patch)
treedf972c0abe2d1d96d4c23ef86eb463da43bce2f4 /src
parentfix calligraphy and erasertools bugs introduced by rev19197 (diff)
downloadinkscape-d4f8d56e508fdc427992fb950c67a98af765f187.tar.gz
inkscape-d4f8d56e508fdc427992fb950c67a98af765f187.zip
Rename LPE: mirror reflect --> mirror symmetry
(bzr r6238)
Diffstat (limited to 'src')
-rw-r--r--src/live_effects/CMakeLists.txt2
-rw-r--r--src/live_effects/Makefile_insert4
-rw-r--r--src/live_effects/effect.cpp8
-rw-r--r--src/live_effects/effect.h2
-rw-r--r--src/live_effects/lpe-mirror_symmetry.cpp (renamed from src/live_effects/lpe-mirror_reflect.cpp)14
-rw-r--r--src/live_effects/lpe-mirror_symmetry.h (renamed from src/live_effects/lpe-mirror_reflect.h)16
6 files changed, 23 insertions, 23 deletions
diff --git a/src/live_effects/CMakeLists.txt b/src/live_effects/CMakeLists.txt
index 38b652106..c50c10357 100644
--- a/src/live_effects/CMakeLists.txt
+++ b/src/live_effects/CMakeLists.txt
@@ -10,7 +10,7 @@ lpe-gears.cpp
lpegroupbbox.cpp
lpe-knot.cpp
lpe-lattice.cpp
-lpe-mirror_reflect.cpp
+lpe-mirror_symmetry.cpp
lpeobject.cpp
lpeobject-reference.cpp
lpe-patternalongpath.cpp
diff --git a/src/live_effects/Makefile_insert b/src/live_effects/Makefile_insert
index 366a94883..b9f864546 100644
--- a/src/live_effects/Makefile_insert
+++ b/src/live_effects/Makefile_insert
@@ -51,8 +51,8 @@ live_effects_liblive_effects_a_SOURCES = \
live_effects/lpe-circle_with_radius.h \
live_effects/lpe-perspective_path.cpp \
live_effects/lpe-perspective_path.h \
- live_effects/lpe-mirror_reflect.cpp \
- live_effects/lpe-mirror_reflect.h \
+ live_effects/lpe-mirror_symmetry.cpp \
+ live_effects/lpe-mirror_symmetry.h \
live_effects/lpe-circle_3pts.cpp \
live_effects/lpe-circle_3pts.h \
live_effects/lpe-angle_bisector.cpp \
diff --git a/src/live_effects/effect.cpp b/src/live_effects/effect.cpp
index 339e5c833..66d2334e0 100644
--- a/src/live_effects/effect.cpp
+++ b/src/live_effects/effect.cpp
@@ -55,7 +55,7 @@
#include "live_effects/lpe-constructgrid.h"
#include "live_effects/lpe-perp_bisector.h"
#include "live_effects/lpe-tangent_to_curve.h"
-#include "live_effects/lpe-mirror_reflect.h"
+#include "live_effects/lpe-mirror_symmetry.h"
#include "live_effects/lpe-circle_3pts.h"
#include "live_effects/lpe-angle_bisector.h"
#include "live_effects/lpe-parallel.h"
@@ -87,7 +87,7 @@ const Util::EnumData<EffectType> LPETypeData[INVALID_LPE] = {
{CONSTRUCT_GRID, N_("Construct grid"), "construct_grid"},
{PERP_BISECTOR, N_("Perpendicular bisector"), "perp_bisector"},
{TANGENT_TO_CURVE, N_("Tangent to curve"), "tangent_to_curve"},
- {MIRROR_REFLECT, N_("Mirror reflection"), "mirror_reflect"},
+ {MIRROR_SYMMETRY, N_("Mirror symmetry"), "mirror_symmetry"},
{CIRCLE_3PTS, N_("Circle through 3 points"), "circle_3pts"},
{ANGLE_BISECTOR, N_("Angle bisector"), "angle_bisector"},
{PARALLEL, N_("Parallel"), "parallel"},
@@ -151,8 +151,8 @@ Effect::New(EffectType lpenr, LivePathEffectObject *lpeobj)
case TANGENT_TO_CURVE:
neweffect = static_cast<Effect*> ( new LPETangentToCurve(lpeobj) );
break;
- case MIRROR_REFLECT:
- neweffect = static_cast<Effect*> ( new LPEMirrorReflect(lpeobj) );
+ case MIRROR_SYMMETRY:
+ neweffect = static_cast<Effect*> ( new LPEMirrorSymmetry(lpeobj) );
break;
case CIRCLE_3PTS:
neweffect = static_cast<Effect*> ( new LPECircle3Pts(lpeobj) );
diff --git a/src/live_effects/effect.h b/src/live_effects/effect.h
index 38c9ccdaa..dc5d6ec4a 100644
--- a/src/live_effects/effect.h
+++ b/src/live_effects/effect.h
@@ -69,7 +69,7 @@ enum EffectType {
CONSTRUCT_GRID,
PERP_BISECTOR,
TANGENT_TO_CURVE,
- MIRROR_REFLECT,
+ MIRROR_SYMMETRY,
CIRCLE_3PTS,
ANGLE_BISECTOR,
PARALLEL,
diff --git a/src/live_effects/lpe-mirror_reflect.cpp b/src/live_effects/lpe-mirror_symmetry.cpp
index 60e307bdb..e41d4084d 100644
--- a/src/live_effects/lpe-mirror_reflect.cpp
+++ b/src/live_effects/lpe-mirror_symmetry.cpp
@@ -1,6 +1,6 @@
-#define INKSCAPE_LPE_MIRROR_REFLECT_CPP
+#define INKSCAPE_LPE_MIRROR_SYMMETRY_CPP
/** \file
* LPE <mirror_reflection> implementation: mirrors a path with respect to a given line.
*/
/*
* Authors:
@@ -13,7 +13,7 @@
* Released under GNU GPL, read the file 'COPYING' for more information
*/
-#include "live_effects/lpe-mirror_reflect.h"
+#include "live_effects/lpe-mirror_symmetry.h"
#include <sp-path.h>
#include <display/curve.h>
#include <svg/path-string.h>
@@ -25,7 +25,7 @@
namespace Inkscape {
namespace LivePathEffect {
-LPEMirrorReflect::LPEMirrorReflect(LivePathEffectObject *lpeobject) :
+LPEMirrorSymmetry::LPEMirrorSymmetry(LivePathEffectObject *lpeobject) :
Effect(lpeobject),
discard_orig_path(_("Discard original path?"), _("Check this to only keep the mirrored part of the path"), "discard_orig_path", &wr, this, false),
reflection_line(_("Reflection line"), _("Line which serves as 'mirror' for the reflection"), "reflection_line", &wr, this, "M0,0 L100,100")
@@ -36,13 +36,13 @@ LPEMirrorReflect::LPEMirrorReflect(LivePathEffectObject *lpeobject) :
registerParameter( dynamic_cast<Parameter *>(&reflection_line) );
}
-LPEMirrorReflect::~LPEMirrorReflect()
+LPEMirrorSymmetry::~LPEMirrorSymmetry()
{
}
void
-LPEMirrorReflect::acceptParamPath (SPPath *param_path) {
+LPEMirrorSymmetry::acceptParamPath (SPPath *param_path) {
using namespace Geom;
SPCurve* curve = sp_path_get_curve_for_edit (param_path);
@@ -59,7 +59,7 @@ LPEMirrorReflect::acceptParamPath (SPPath *param_path) {
}
std::vector<Geom::Path>
-LPEMirrorReflect::doEffect_path (std::vector<Geom::Path> const & path_in)
+LPEMirrorSymmetry::doEffect_path (std::vector<Geom::Path> const & path_in)
{
std::vector<Geom::Path> path_out;
if (!discard_orig_path) {
@@ -1,6 +1,6 @@
/** \file
- * LPE <mirror_reflection> implementation: mirrors a path with respect to a given line.
+ * LPE <mirror_symmetry> implementation: mirrors a path with respect to a given line.
*/
/*
diff --git a/src/live_effects/lpe-mirror_reflect.h b/src/live_effects/lpe-mirror_symmetry.h
index 4fd695e0e..40b0292c4 100644
--- a/src/live_effects/lpe-mirror_reflect.h
+++ b/src/live_effects/lpe-mirror_symmetry.h
@@ -1,8 +1,8 @@
-#ifndef INKSCAPE_LPE_MIRROR_REFLECT_H
-#define INKSCAPE_LPE_MIRROR_REFLECT_H
+#ifndef INKSCAPE_LPE_MIRROR_SYMMETRY_H
+#define INKSCAPE_LPE_MIRROR_SYMMETRY_H
/** \file
* LPE <mirror_reflection> implementation: mirrors a path with respect to a given line.
*/
/*
* Authors:
@@ -23,10 +23,10 @@
namespace Inkscape {
namespace LivePathEffect {
-class LPEMirrorReflect : public Effect {
+class LPEMirrorSymmetry : public Effect {
public:
- LPEMirrorReflect(LivePathEffectObject *lpeobject);
- virtual ~LPEMirrorReflect();
+ LPEMirrorSymmetry(LivePathEffectObject *lpeobject);
+ virtual ~LPEMirrorSymmetry();
virtual void acceptParamPath (SPPath *param_path);
virtual int acceptsNumParams() { return 2; }
@@ -37,8 +37,8 @@ private:
BoolParam discard_orig_path;
PathParam reflection_line;
- LPEMirrorReflect(const LPEMirrorReflect&);
- LPEMirrorReflect& operator=(const LPEMirrorReflect&);
+ LPEMirrorSymmetry(const LPEMirrorSymmetry&);
+ LPEMirrorSymmetry& operator=(const LPEMirrorSymmetry&);
};
} //namespace LivePathEffect
@@ -1,8 +1,8 @@
/** \file
- * LPE <mirror_reflection> implementation: mirrors a path with respect to a given line.
+ * LPE <mirror_symmetry> implementation: mirrors a path with respect to a given line.
*/
/*